(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{21:function(e,t,a){e.exports=a(31)},31:function(e,t,a){"use strict";a.r(t);var r,n,i=a(1),o=a.n(i),s=a(19),l=a.n(s),c=a(17),m=a(11),u=a(13),d=a(9),p=a(20),g=a.n(p),h=function(e){return m.a.setFrameHeight(),document.createTextNode(e)},f=function(e){var t=e.theme,a=e.value,r=e.animateFrom,n=e.useTypewriter,i=u.a.div({display:"inline-block",background:t.secondaryBackgroundColor,border:"1px solid transparent",borderRadius:"10px",padding:"10px 14px",margin:"5px 20px",maxWidth:"70%",whiteSpace:"pre-wrap"});return n?(console.log("rendering with typewriter"),o.a.createElement(i,null,o.a.createElement(g.a,{options:{delay:10,cursor:"\u258e",onCreateTextNode:h},onInit:function(e){e.pasteString(r,null).typeString(a.split(r).join("")).callFunction((function(t){setTimeout((function(){return t.elements.cursor.setAttribute("hidden","hidden")}),3500),e.stop()})).start()}}))):o.a.createElement(i,null,a)},b=Object(m.b)((function(e){Object(i.useEffect)((function(){m.a.setFrameHeight()}));var t,a=e.args,s=a.isUser,l=a.avatarStyle,p=a.seed,g=a.animateFrom,h=a.value,b=a.useTypewriter;t=l.startsWith("https")||l.startsWith("data:image")?l:"https://avatars.dicebear.com/api/".concat(l,"/").concat(p,".svg");var v=e.theme;if(!v)return o.a.createElement("div",null,"Theme is undefined, please check streamlit version.");var x=u.a.img({border:"1px solid transparent",height:"3rem",width:"3rem",margin:0}),E=u.a.div({display:"flex",fontFamily:"".concat(v.font,", 'Segoe UI', 'Roboto', sans-serif"),height:"auto",margin:0,width:"100%"},(function(e){return e.isUser?Object(d.a)(r||(r=Object(c.a)(["\n        flex-direction: row-reverse;\n        & > div {\n          text-align: right;\n        }\n        padding-right: 5px;\n      "]))):Object(d.a)(n||(n=Object(c.a)([""])))}));return s?o.a.createElement(E,{isUser:s},o.a.createElement(x,{src:t,alt:"profile",draggable:"false"}),o.a.createElement(f,{theme:v,value:h,animateFrom:g})):o.a.createElement(E,{isUser:s},o.a.createElement(x,{src:t,alt:"profile",draggable:"false"}),o.a.createElement(f,{theme:v,value:h,animateFrom:g,useTypewriter:b}))}));l.a.render(o.a.createElement(o.a.StrictMode,null,o.a.createElement(b,null)),document.getElementById("root"))}},[[21,1,2]]]);
//# sourceMappingURL=main.9a50526f.chunk.js.map